@@ -30,7 +30,9 @@ sub _build_converter {
 }
 
 sub convert {
-    args my $self, my $parsed_response => 'HashRef|ArrayRef';
+    args my $self, my $parsed_response => 'HashRef|ArrayRef',
+      my $request => 'WebService::Async::Request',
+      my $async   => 'WebService::Async';
     my @args = %{$self->param};
     return $self->converter->XMLout($parsed_response, @args);
 }
